@@ -3,38 +3,35 @@ import argparse
 import os
 import pathlib
 
-from .linters.common import DEFAULT_MESSAGE_FORMAT
-from .linters.lint import lint
+from python_dev_tools.linters.common import DEFAULT_MESSAGE_FORMAT
+from python_dev_tools.linters.lint import lint
 
 
 def udpate_os_path():
     """Update PATH env variable to find linters."""
     script_path = pathlib.Path(__file__).resolve()
     os.environ["PATH"] = "".join(
-        (str(script_path.parent), os.pathsep, os.environ["PATH"])
+        (str(script_path.parent), os.pathsep, os.environ["PATH"]),
     )
 
     # replace /lib/ with /bin/, and add to PATH
     for parent in reversed(script_path.parents):
         if parent.stem == "lib":
             os.environ["PATH"] = "".join(
-                (str(parent.parent / "bin"), os.pathsep, os.environ["PATH"])
+                (str(parent.parent / "bin"), os.pathsep, os.environ["PATH"]),
             )
 
 
 def main():
     """Entry point."""
     parser = argparse.ArgumentParser(
-        description="Python linter combining existing linters"
+        description="Python linter combining existing linters",
     )
     parser.add_argument(
-        "file", metavar="FILE", type=str, help="path of the file to lint"
+        "file", metavar="FILE", type=str, help="path of the file to lint",
     )
     parser.add_argument(
-        "-f",
-        "--format",
-        default=DEFAULT_MESSAGE_FORMAT,
-        help="format of the output",
+        "-f", "--format", default=DEFAULT_MESSAGE_FORMAT, help="format of the output",
     )
     parser.add_argument(
         "-a",
